Creates sample ASCII files in a temporary directory for demonstrating the parser functions.
Usage
pr_example_files(type = c("insole", "saddle", "platform", "all"))Examples
path <- pr_example_files("insole")
file.exists(path)
#> [1] TRUE
Creates sample ASCII files in a temporary directory for demonstrating the parser functions.
pr_example_files(type = c("insole", "saddle", "platform", "all"))path <- pr_example_files("insole")
file.exists(path)
#> [1] TRUE