Skip to contents

Performs bilinear interpolation on the maximum pressure picture between active sensor positions to produce a smoother image. The underlying trial data is not modified.

Usage

pr_interpolate(trial, factor = 2L)

Arguments

trial

A pr_trial object.

factor

Integer. Interpolation factor in each dimension. Default 2.

Value

A list with pressure_interp (interpolated matrix), x_mm, y_mm.

Examples

out <- pr_interpolate(pr_example_trial("insole"), factor = 2)
dim(out$pressure_interp)
#> [1] 35 15