Overlays COP trajectories from each detected stance phase, centered on heel strike.
Arguments
- trial
A pr_trial object.
- cycles
Output of
pr_calc_gait_cycles(). IfNULL, auto-detected.
Examples
pr_plot_cop_butterfly(pr_example_trial("insole"))
Overlays COP trajectories from each detected stance phase, centered on heel strike.
A pr_trial object.
Output of pr_calc_gait_cycles(). If NULL, auto-detected.
pr_plot_cop_butterfly(pr_example_trial("insole"))