Skip to contents

Opens a Shiny application for importing, analyzing, and visualizing pressure measurement data. The app has six tabs: Import, Heatmap, Regions, Dynamics, Comparison, and Report.

Usage

pr_run_app(trial = NULL, ...)

Arguments

trial

A pr_trial object to pre-load. If NULL (default), the app starts empty and the user can load data from the Import tab.

...

Additional arguments passed to shiny::runApp().

Value

Invisible NULL. Called for side effects: launches the Shiny application.

Examples

# \donttest{
if (interactive()) {
  pr_run_app(pr_example_trial("saddle_horse"))
}
# }