Performs bilinear interpolation on the maximum pressure picture between active sensor positions to produce a smoother image. The underlying trial data is not modified.
Arguments
- trial
A pr_trial object.
- factor
Integer. Interpolation factor in each dimension. Default
2.
Examples
out <- pr_interpolate(pr_example_trial("insole"), factor = 2)
dim(out$pressure_interp)
#> [1] 35 15