Opens a Shiny application for importing, analyzing, and visualizing pressure measurement data. The app has six tabs: Import, Heatmap, Regions, Dynamics, Comparison, and Report.
Arguments
- trial
A pr_trial object to pre-load. If
NULL(default), the app starts empty and the user can load data from the Import tab.- ...
Additional arguments passed to
shiny::runApp().
Examples
# \donttest{
if (interactive()) {
pr_run_app(pr_example_trial("saddle_horse"))
}
# }